/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_ImageCaptureErrorEvent_h
#define mozilla_dom_ImageCaptureErrorEvent_h

#include "mozilla/Attributes.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingUtils.h"
#include "mozilla/dom/Event.h"
#include "mozilla/dom/ImageCaptureErrorEventBinding.h"

struct JSContext;
namespace mozilla {
namespace dom {

class ImageCaptureErrorEvent : public Event
{
public:
  NS_DECL_ISUPPORTS_INHERITED
  NS_DECL_CYCLE_COLLECTION_SCRIPT_HOLDER_CLASS_INHERITED(ImageCaptureErrorEvent, Event)
protected:
  virtual ~ImageCaptureErrorEvent();
  explicit ImageCaptureErrorEvent(mozilla::dom::EventTarget* aOwner);

  nsRefPtr<ImageCaptureError> mImageCaptureError;

public:
  virtual ImageCaptureErrorEvent* AsImageCaptureErrorEvent() MOZ_OVERRIDE;

  virtual JSObject* WrapObjectInternal(JSContext* aCx) MOZ_OVERRIDE;

  static already_AddRefed<ImageCaptureErrorEvent> Constructor(mozilla::dom::EventTarget* aOwner, const nsAString& aType, const ImageCaptureErrorEventInit& aImageCaptureErrorInitDict);

  static already_AddRefed<ImageCaptureErrorEvent> Constructor(const GlobalObject& aGlobal, const nsAString& aType, const ImageCaptureErrorEventInit& aImageCaptureErrorInitDict, ErrorResult& aRv);

  ImageCaptureError* GetImageCaptureError() const;
};

} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_ImageCaptureErrorEvent_h
